Enhanced family conversion supporting all standard and additional families with automatic routing to specialised implementations when enabled.
convert_family_to_inla(family, quantile = 0.5, allow_ordinal_routing = FALSE)Character string, list, or routing object specifying family/routing info
A family object, character string, or list specifying the response distribution
Numeric value between 0 and 1 for quantile regression
Logical; if TRUE, enables routing for ordinal families