Learn R Programming

qbrms (version 1.0.1)

prior_checks: Prior Predictive Checks and Density Plotting

Description

Functions for prior checks and density plotting with ggplot2 extensibility.

Arguments

Details

This file provides functionality for prior predictive checks and density plotting that integrates with ggplot2 for full customisation.