Learn R Programming

qbrms (version 1.0.1)

qbrms-model-criteria: Model comparison criteria for qbrms models

Description

Compute approximate DIC, LOO and WAIC for qbrms model fits.

Usage

waic(object, ...)

loo(object, ...)

dic(object, ...)

# S3 method for qbrms_fit waic(object, ...)

# S3 method for qbrms_fit loo(object, ...)

# S3 method for qbrms_fit dic(object, ...)

Value

For dic(), loo() and waic() methods on qbrms_fit objects, a list containing the corresponding criterion (for example, list(dic = ...), list(looic = ..., elpd_loo = ...), or list(waic = ...)). If the criterion cannot be computed, NA_real_

is returned.

Arguments

object

A qbrms_fit object.

...

Additional arguments passed to internal methods or underlying tools.

Details

These functions provide generic interfaces (dic(), loo(), waic()) and S3 methods for qbrms_fit objects that extract the corresponding criteria from the underlying INLA fit where available.