Learn R Programming

qbrms (version 1.0.1)

qbrms_fit_log: Get captured fit log from a qbrms object (if available)

Description

Get captured fit log from a qbrms object (if available)

Usage

qbrms_fit_log(x)

Value

A character vector of captured console lines, or NULL if none

Arguments

x

A qbrms_fit / qbrmO_fit object returned by qbrm()/qbrms()