Learn R Programming

qbrms (version 1.0.1)

student_t: Student's t Family for Robust Regression

Description

Student's t-distribution family for robust regression with heavier tails than Gaussian to handle outliers.

Functions that act as both family constructors (for qbrm) and prior specifications (for prior), depending on arguments.

Usage

student_t(
  link_or_df = "identity",
  location = 0,
  scale = 1,
  link = NULL,
  link.sigma = "log",
  link.nu = "log",
  ...
)

student()

student_t( link_or_df = "identity", location = 0, scale = 1, link = NULL, link.sigma = "log", link.nu = "log", ... )

student_t_prior( link_or_df = 3, location = 0, scale = 1, link.sigma = "log", link.nu = "log" )

Value

An object of class "family" specifying the Student-t distribution.

An object of class "family" specifying the Student-t distribution.

A family object or prior object depending on inputs.

Arguments

link_or_df

For family: link function (character). For prior: degrees of freedom (numeric).

location

Location parameter (prior only).

scale

Scale parameter (prior only).

link

Optional link function (if acting as family).

link.sigma

Link for sigma (family only).

link.nu

Link for nu (family only).

...

Additional arguments.

Examples

Run this code
# Create a Student-t family object
fam <- student_t()
print(fam$family)

Run the code above in your browser using DataLab