compute_adaptive_threshold_priors: Compute Data-Driven Threshold Priors
Description
Calculate threshold priors based on empirical quantiles to match brms centering
Usage
compute_adaptive_threshold_priors(y_ordered, method = "quantile")
Value
List with threshold means, standard deviations, and empirical baseline
Arguments
- y_ordered
Ordered factor response variable
- method
Method for computing adaptive priors ("quantile" or "cumulative_mean")